# bids-on-flywheel
A walkthrough on making sure your data is BIDS-compliant on flywheel and how to upload it.

See the [wiki](https://github.com/PennBBL/bids-on-flywheel/wiki) for more, or get started right away with command-line tools:
```
pip install flywheel-bids-tools
```
